import calendar
import datetime
import feedparser
import random
import time

from django.core.cache import cache
from django.shortcuts import render_to_response

from zeitgeistwebsite.settings import ANNOUNCEMENT_FEED_URL, BLOG_FEED_URLS

def _fetch_announcements(limit=10):
    announcements = cache.get('feed_announcements')
    if announcements is None:
        announcements = cache.get('feed_announcements',
            feedparser.parse(ANNOUNCEMENT_FEED_URL).entries)
        for entry in announcements:
            entry.date = datetime.datetime(*(entry.updated_parsed[0:6]))
        cache.set('feed_announcements', announcements, 300)

    return announcements[:limit]

def _fetch_blogs(limit=10):
    blogs = cache.get('feed_blogs')
    if blogs is None:
        blogs = []
        for blog_feed_url in BLOG_FEED_URLS:
            blog_feed = feedparser.parse(blog_feed_url)
            blogs.extend(blog_feed.entries)
        blogs = sorted(blogs, key=lambda entry: 
            time.mktime(entry.updated_parsed), reverse=True)
        for entry in blogs:
            entry.date = datetime.datetime(*(entry.updated_parsed[0:6]))
        cache.set('feed_blogs', blogs, 300)

    return blogs[:limit]

def index(request):
    apps = (
        {"name": "GNOME Activity Journal",
         "url": "https://edge.launchpad.net/gnome-zeitgeist",
         "img": "/static/img/apps/gnome-activity-journal.png"},
    )

    return render_to_response('index.html', {
        "announcement_feed_url": ANNOUNCEMENT_FEED_URL,
        "announcements": _fetch_announcements(2),
        "blogs": _fetch_blogs(2),
        "app": random.choice(apps),
    })

def static_view(request, template_name):
    return render_to_response(template_name, {})

def blogs(request):
    return render_to_response('blogs.html', {
        "blogs": _fetch_blogs(10),
    })
